@@ -4,7 +4,7 @@ from typing import Optional
 from telescope_sdk.common import UserFacingDataType
 
 
-class ProspectInteractionEventType(Enum):
+class ProspectInteractionEventType(str, Enum):
     PROSPECT_REPLIED_POSITIVE = 'PROSPECT_REPLIED_POSITIVE'
     PROSPECT_REPLIED_NEGATIVE = 'PROSPECT_REPLIED_NEGATIVE'
     PROSPECT_REPLIED_UNKNOWN_SENTIMENT = 'PROSPECT_REPLIED_UNKNOWN_SENTIMENT'
